@@ -391,12 +391,23 @@ class MotionProgram(object):
             wait_cmd.value = value
         self.addCommand(wait_cmd, self.__MotionSpec.WAIT)
 
+    def createSetType(self, value):
+        if isinstance(value, bool):
+            return self.__MotionSpec.Set(), self.__MotionSpec.SET
+        elif isinstance(value, int):
+            return self.__MotionSpec.SetInt(), self.__MotionSpec.SETINT
+        elif isinstance(value, float):
+            return self.__MotionSpec.SetDouble(), self.__MotionSpec.SETDOUBLE
+
+        raise TypeError(f"Value must be float, int, or bool, got {type(value).__name__}")
+
+
     def addSet(self, path, value):
-        set_cmd = self.__MotionSpec.Set()
+        set_cmd, set_type = self.createSetType(value)
         if path is not None:
             set_cmd.path = path
             set_cmd.value = value
-        self.addCommand(set_cmd, self.__MotionSpec.SET)
+        self.addCommand(set_cmd, set_type)
 
 
     def generateMessage(self, program_name='Undefined', system_id=0):
