@@ -6,6 +6,7 @@
 #
 
 import time
+
 from .system_defs import States, StateEvents, ModeCommands, Modes, InterpreterEvents, InterpreterStates, \
     MotionGeneratorStates
 
@@ -113,6 +114,34 @@ class RobotCommand(object):
 
         return True
 
+    def acknowledge(self, timeout_s=20.0):
+        """Acknowledge the errors and warnings. If robot is in EStop state brings it to the Off state,
+        if robot is in ForceDisengaged/ForceIdle state brings it to the Disengaged/Idle state.
+
+            Returns:
+                bool: True if operation is completed, False if failed
+        """
+
+        actual_state = self.__req.getParameter("root/Logic/state").get().value[0]
+        self.__req.setParameter("root/Logic/stateCommand", StateEvents.ACKNOWLEDGE_ERROR.value).get()
+        if actual_state == States.ESTOP_OFF_S.value or actual_state == States.RESET_ESTOP_T.value:
+            return self.__waitForTheParameterValuet("root/Logic/state", States.OFF_S.value, timeout_s)
+        elif actual_state == States.FORCEDISENGAGED_S.value or actual_state == States.RESET_FORCEDDISENGAGE_T.value:
+            return self.__waitForTheParameterValuet("root/Logic/state", States.DISENGAGED_S.value, timeout_s)
+
+        return True
+
+    def __waitForTheParameterValuet(self, parameter_name, target_value, timeout_s):
+        timer = 0
+        actual_vale = None
+        while timer <= timeout_s:
+            actual_vale = self.__req.getParameter(parameter_name).get().value[0]
+            if actual_vale == target_value:
+                return True
+            time.sleep(0.1)
+            timer += 0.1
+        return False
+
     def manualCartMode(self):
         """Switch robot to a manual Cartesian motion.
 
